@@ -16,18 +16,18 @@
  */
 package org.apache.commons.io.output;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.IOException;
 import java.io.OutputStream;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
- * JUnit Test Case for {@link CloseShieldOutputStream}.
+ * Tests {@link CloseShieldOutputStream}.
  */
 public class CloseShieldOutputStreamTest {
 
@@ -37,7 +37,7 @@ public class CloseShieldOutputStreamTest {
 
     private boolean closed;
 
-    @Before
+    @BeforeEach
     public void setUp() {
         original = new ByteArrayOutputStream() {
             @Override
@@ -45,20 +45,15 @@ public class CloseShieldOutputStreamTest {
                 closed = true;
             }
         };
-        shielded = new CloseShieldOutputStream(original);
+        shielded = CloseShieldOutputStream.wrap(original);
         closed = false;
     }
 
     @Test
     public void testClose() throws IOException {
         shielded.close();
-        assertFalse("closed", closed);
-        try {
-            shielded.write('x');
-            fail("write(b)");
-        } catch (final IOException ignore) {
-            // expected
-        }
+        assertFalse(closed, "closed");
+        assertThrows(IOException.class, () -> shielded.write('x'), "write(b)");
         original.write('y');
         assertEquals(1, original.size());
         assertEquals('y', original.toByteArray()[0]);
