@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,24 +16,16 @@
  */
 package org.apache.commons.io.output;
 
-
-import org.junit.Test;
-
 import java.io.IOException;
 
+import org.junit.jupiter.api.Test;
 
 /**
- * Really not a lot to do here, but checking that no 
- * Exceptions are thrown. 
- *
- * @version $Id: NullOutputStreamTest.java 1718944 2015-12-09 19:50:30Z krosenvold $
+ * Tests {@link NullOutputStream}.
  */
-
 public class NullOutputStreamTest {
 
-    @Test
-    public void testNull() throws IOException {
-        final NullOutputStream nos = new NullOutputStream();
+    private void process(final NullOutputStream nos) throws IOException {
         nos.write("string".getBytes());
         nos.write("some string".getBytes(), 3, 5);
         nos.write(1);
@@ -44,4 +36,18 @@ public class NullOutputStreamTest {
         nos.write(255);
     }
 
+    @Test
+    public void testNewInstance() throws IOException {
+        try (NullOutputStream nos = NullOutputStream.INSTANCE) {
+            process(nos);
+        }
+    }
+
+    @Test
+    public void testSingleton() throws IOException {
+        try (NullOutputStream nos = NullOutputStream.INSTANCE) {
+            process(nos);
+        }
+    }
+
 }
